@@ -19,22 +19,24 @@
 #define LIBPLACEBO_CONFIG_H_
 
 // Increased any time the library changes in a fundamental/major way.
-#define PL_MAJOR_VER 0
+#define PL_MAJOR_VER 1
 
 // Increased any time the API changes. (Note: Does not reset when PL_MAJOR_VER
 // is increased)
-#define PL_API_VER 4
+#define PL_API_VER 7
 
 // Increased any time a fix is made to a given API version.
 #define PL_FIX_VER 0
 
 // Friendly name (`git describe`) for the overall version of the library
-#define PL_VERSION "v0.4.0"
+#define PL_VERSION "v1.7.0"
 
 // Feature tests. These aren't described in further detail, but may be useful
 // for programmers wanting to programmatically check for feature support
-// in their compiled libshaderc versions.
-#define PL_HAVE_SHADERC 0
+// in their compiled libplacebo versions.
+#define PL_HAVE_LCMS 1
+#define PL_HAVE_GLSLANG 1
+#define PL_HAVE_SHADERC 1
 #define PL_HAVE_VULKAN 1
 
 
